#ifndef SLALIBHDEF
#define SLALIBHDEF

/*
**  - - - - - - - - -
**   s l a l i b . h     !!! special version for STARBASE !!!
**  - - - - - - - - -
**
**  Prototype function declarations for slalib library.
**
**  Last revision:   8 May 2011
**
**  Copyright P.T.Wallace.  All rights reserved.
*/

#include <math.h>

/* Star-independent ICRS-to-CIRS parameters */
typedef struct {
   double pmt;        /* time interval for proper motion (Julian years) */
   double eb[3];      /* SSB to Earth (AU) */
   double ehn[3];     /* Sun to Earth unit vector */
   double gr2e;       /* (grav rad Sun)*2/(Sun-Earth distance) */
   double abv[3];     /* barycentric Earth velocity in units of c */
   double ab1;        /* sqrt(1-v**2) where v=modulus(abv) */
   double bpn[3][3];  /* bias-precession-nutation matrix */
} CIpars;

/* Star-independent intermediate-to-observed parameters */
typedef struct {
   double along;      /* longitude + s' + dERA(DUT) (radians) */
   double phi;        /* geodetic latitude (radians) */
   double hm;         /* height above sea level (metres) */
   double xpl;        /* polar motion xp wrt local meridian (radians) */
   double ypl;        /* polar motion yp wrt local meridian (radians) */
   double sphi;       /* sine of geodetic latitude */
   double cphi;       /* cosine of geodetic latitude */
   double diurab;     /* magnitude of diurnal aberration vector */
   double p;          /* pressure (mb,hPa) */
   double tk;         /* ambient temperature (K) */
   double rh;         /* relative humidity (0-1) */
   double tlr;        /* tropospheric lapse rate (K per metre) */
   double wl;         /* wavelength (micron) or minus frequency (GHz) */
   double refa;       /* refraction constant A (radians) */
   double refb;       /* refraction constant B (radians) */
   double eral;       /* "Local" Earth Rotation Angle (radians) */
} IOpars;

#ifdef __cplusplus
extern "C" {
#endif

void slaAddet ( double, double, double, double*, double* );

double slaAirmas ( double zd );

void slaAoppa ( double, double, double, double,
                double, double, double, double, double,
                double, double, double, double[14] );

void slaAoppat ( double, double[14] );

void slaAopqk ( double, double, double[14], double*, double*, double*,
                double*, double* );

double slaDbear ( double, double, double, double );

void slaDcc2s ( double[3], double*, double* );

void slaDcmpf ( double[6], double*, double*, double*,
                double*, double*, double* );

void slaDcs2c ( double, double, double[3] );

void slaDeuler ( const char*, double, double, double, double[3][3] );

void slaDimxv ( double[3][3], double[3], double[3] );

void slaDmat ( int, double*, double*, double*, int*, int* );

void slaDmoon ( double, double[6] );

void slaDmxm ( double[3][3], double[3][3], double[3][3] );

void slaDmxv ( double[3][3], double[3], double[3] );

double slaDrange ( double );

double slaDranrm ( double );

void slaDs2tp ( double, double, double, double, double*, double*, int* );

double slaDsep ( double, double, double, double );

double slaDt ( double );

void slaDtp2s ( double, double, double, double, double*, double* );

double slaDvdv ( double[3], double[3] );

void slaDvn ( double[3], double[3], double* );

void slaEg50 ( double, double, double*, double* );

void slaEl2ue ( double, int, double, double, double, double, double,
                double, double, double, double[], int* );

double slaEpj ( double );

double slaEpb2d ( double );

double slaEqeqx ( double );

void slaEqgal ( double, double, double*, double* );

void slaEtrms ( double, double[3] );

void slaEvp ( double, double, double[3], double[3], double[3], double[3] );

void slaFitxy ( int, int, double[][2], double[][2], double[6], int* );

void slaFk425 ( double, double, double, double, double, double,
                double*, double*, double*, double*, double*, double* );

void slaFk45z ( double, double, double, double*, double* );

void slaFk524 ( double, double, double, double, double, double,
                double*, double*, double*, double*, double*, double* );

void slaFk54z ( double, double, double, double*, double*,
                double*, double* );

void slaGaleq ( double, double, double*, double* );

void slaGe50 ( double, double, double*, double* );

void slaGeoc ( double, double, double*, double* );

double slaGmst ( double );

void slaInvf ( double[6], double[6], int* );

void slaMappa ( double, double, double[21] );

void slaMapqkz ( double, double, double[21], double*, double* );

void slaNut ( double, double[3][3] );

void slaNutc ( double, double*, double*, double* );

void slaObs ( int, char*, char*, double*, double*, double* );

double slaPa ( double, double, double );

void slaPlanel ( double, int, double, double, double, double, double,
                 double, double, double, double[6], int* );

void slaPlanet ( double, int, double[6], int* );

void slaPm ( double, double, double, double, double, double, double,
             double, double*, double* );

void slaPrebn ( double, double, double[3][3] );

void slaPrec ( double, double, double[3][3] );

void slaPreces ( const char[3], double, double, double*, double* );

void slaPrenut ( double, double, double[3][3] );

void slaPv2ue ( double[], double, double, double[], int* );

void slaPvobs ( double, double, double, double[6] );

void slaPxy ( int, double[][2], double[][2], double[6],
              double[][2], double*, double*, double* );

void slaRdplan ( double, int, double, double, double*, double*, double* );

void slaRefco ( double, double, double, double, double, double, double,
                double, double*, double* );

void slaRefro ( double, double, double, double, double, double, double,
                double, double, double* );

void slaRefz ( double, double, double, double* );

void slaSubet ( double, double, double, double*, double* );

void slaSvd ( int, int, int, int, double*, double*, double*, double*, int* );

void slaSvdcov ( int, int, int, double*, double*, double*, double* );

void slaSvdsol ( int, int, int, int, double*, double*, double*, double*,
                 double*, double* );

void slaUe2pv ( double, double[], double[], int* );

void slaXy2xy ( double, double, double[6], double*, double* );

#ifdef __cplusplus
}
#endif

#endif
